==> dl.php?src=linea21_1_0.zip: linea21/public/tpl_dashboard.php <==
<?php

//////////////////////////////////////////
/////rcupration des variables GET et POST
//////////////////////////////////////////
include_once('../dashboard/display.php');
if (isset($_REQUEST['parentid'])) 
{
$sdi_id=$_REQUEST['id'];
$scale_id=$_REQUEST['parentid'];
}
else if (isset($_REQUEST['id'])) {
 $scale_id=$_REQUEST['id'];   
}
else $scale_id=1;

?>
<div id="contenu">
<?php
//////////////////////////////////////////
/////affichage switch d'affichage jeune public / classique
//////////////////////////////////////////

	if(!isset($_REQUEST['parentid']))
	
	if ($GLOBALS['links'][$GLOBALS['activeitem']]['linkvalue']==$GLOBALS['links']['tableau-de-bord-idd']['linkvalue']){ 
	//////////////////////////////////////////
/////affichage liste des indicateurs classique
//////////////////////////////////////////
	echo "<h1>".$GLOBALS['lang']['dashboard']['list_public']."</h1>".END_LINE;
		?><div class="h1_comment" id="h1_dashboard">
<?php echo $GLOBALS['lang']['dashboard']['h1_public_comment']; ?>
</div>
	<?php 
		echo DisplaySwitchAffichage($scale_id);
		echo "<hr />";
	DisplayListValues($scale_id, $GLOBALS['filter']['echelle']['linkvalue']);
	echo "<br />";
	}
//////////////////////////////////////////
/////affichage tableau de bord jeune
//////////////////////////////////////////
	else {
	echo "<h1>".$GLOBALS['lang']['dashboard']['list_public_anim']."</h1>".END_LINE;
	?><div class="h1_comment" id="h1_dashboard">
<?php echo $GLOBALS['lang']['dashboard']['h1_public_comment']; ?>
</div>
	<?php 
		echo DisplaySwitchAffichage($scale_id);
		echo "<hr />";
	echo DisplayYoung();
	}
	//////////////////////////////////////////
/////affichage dtail d'un indicateur
//////////////////////////////////////////
	if(isset($_REQUEST['parentid']) && $GLOBALS['links'][$GLOBALS['activeitem']]['linkvalue']==$GLOBALS['links']['tableau-de-bord-idd']['linkvalue']) DisplayOneSdi($sdi_id, $scale_id);
	if (isset($_REQUEST['parentid']) && $GLOBALS['links'][$GLOBALS['activeitem']]['linkvalue']==$GLOBALS['links']['tableau-de-bord-idd-reglementation']['linkvalue']) DisplayOneSdirules($sdi_id, $scale_id);
		if (isset($_REQUEST['parentid']) && $GLOBALS['links'][$GLOBALS['activeitem']]['linkvalue']==$GLOBALS['links']['tableau-de-bord-idd-evaluation']['linkvalue']) DisplayOneSdievaluation($sdi_id, $scale_id);
			if (isset($_REQUEST['parentid']) && $GLOBALS['links'][$GLOBALS['activeitem']]['linkvalue']==$GLOBALS['links']['tableau-de-bord-idd-fournisseur']['linkvalue']) DisplayOneSdiprovider($sdi_id, $scale_id);
	?>
</div>

==> dl.php?src=linea21_1_1.zip: linea21/public/tpl_dashboard.php <==
<?php

//////////////////////////////////////////
/////récupération des variables GET et POST
//////////////////////////////////////////
include_once('../dashboard/display.php');
if (isset($_REQUEST['parentid'])) 
{
$sdi_id=$_REQUEST['id'];
$scale_id=$_REQUEST['parentid'];
}
else if (isset($_REQUEST['id'])) {
 $scale_id=$_REQUEST['id'];   
}
else $scale_id=1;

?>
<div id="contenu">
<?php
//////////////////////////////////////////
/////affichage switch d'affichage jeune public / classique
//////////////////////////////////////////

	if(!isset($_REQUEST['parentid']))
	
	if ($GLOBALS['links'][$GLOBALS['activeitem']]['linkvalue']==$GLOBALS['links']['tableau-de-bord-idd']['linkvalue']){ 
	//////////////////////////////////////////
/////affichage liste des indicateurs classique
//////////////////////////////////////////
	echo "<h1>".$GLOBALS['lang']['dashboard']['list_public']."</h1>".END_LINE;
		?><div class="h1_comment" id="h1_dashboard">
<?php echo $GLOBALS['lang']['dashboard']['h1_public_comment']; ?>
</div>
	<?php 
		echo DisplaySwitchAffichage($scale_id);
		echo "<hr />";
	DisplayListValues($scale_id, $GLOBALS['filter']['echelle']['linkvalue']);
	echo "<br />";
	}
//////////////////////////////////////////
/////affichage tableau de bord jeune
//////////////////////////////////////////
	else {
	echo "<h1>".$GLOBALS['lang']['dashboard']['list_public_anim']."</h1>".END_LINE;
	?><div class="h1_comment" id="h1_dashboard">
<?php echo $GLOBALS['lang']['dashboard']['h1_public_comment']; ?>
</div>
	<?php 
		echo DisplaySwitchAffichage($scale_id);
		echo "<hr />";
	echo DisplayYoung();
	}
	//////////////////////////////////////////
/////affichage détail d'un indicateur
//////////////////////////////////////////
	if(isset($_REQUEST['parentid']) && $GLOBALS['links'][$GLOBALS['activeitem']]['linkvalue']==$GLOBALS['links']['tableau-de-bord-idd']['linkvalue']) DisplayOneSdi($sdi_id, $scale_id);
	if (isset($_REQUEST['parentid']) && $GLOBALS['links'][$GLOBALS['activeitem']]['linkvalue']==$GLOBALS['links']['tableau-de-bord-idd-reglementation']['linkvalue']) DisplayOneSdirules($sdi_id, $scale_id);
		if (isset($_REQUEST['parentid']) && $GLOBALS['links'][$GLOBALS['activeitem']]['linkvalue']==$GLOBALS['links']['tableau-de-bord-idd-evaluation']['linkvalue']) DisplayOneSdievaluation($sdi_id, $scale_id);
			if (isset($_REQUEST['parentid']) && $GLOBALS['links'][$GLOBALS['activeitem']]['linkvalue']==$GLOBALS['links']['tableau-de-bord-idd-fournisseur']['linkvalue']) DisplayOneSdiprovider($sdi_id, $scale_id);
	?>
</div>
